@@ -40,10 +40,7 @@ class Dataset:
             self._pynx_version = None
 
     def __repr__(self):
-        return "Dataset {}{}.\n".format(
-            self.sample_name,
-            self.scan,
-        )
+        return f"Dataset {self.sample_name}{self.scan}.\n"
 
     def __str__(self):
         return repr(self)
@@ -179,13 +176,13 @@ class Dataset:
                 # Also copy mode data to entry_1.image_2.modes_percentage
                 if self.reconstruction_file.endswith(".h5"):
                     try:
-                        self.reconstruction_file.copy(
+                        reconstruction_file.copy(
                             '/entry_1/data_2/',
                             f["entry_1"]["image_2"],
                             name="modes_percentage")
                     except RuntimeError:
                         del f["entry_1"]["image_2"]["modes_percentage"]
-                        self.reconstruction_file.copy(
+                        reconstruction_file.copy(
                             '/entry_1/data_2/',
                             f["entry_1"]["image_2"],
                             name="modes_percentage")
@@ -203,12 +200,18 @@ class Dataset:
         # Add GUI data
         with h5py.File(final_cxi_file, "a") as f:
             # Save packages version
-            f.create_dataset("gwaihir_version", data="gwaihir %s" %
-                             self._gwaihir_version)
-            f.create_dataset("bcdi_version", data="bcdi %s" %
-                             self._bcdi_version)
-            f.create_dataset("pynx_version", data="pynx %s" %
-                             self._pynx_version)
+            f.create_dataset(
+                "gwaihir_version",
+                data=f"gwaihir {self._gwaihir_version}"
+            )
+            f.create_dataset(
+                "bcdi_version",
+                data=f"bcdi {self._bcdi_version}"
+            )
+            f.create_dataset(
+                "pynx_version",
+                data=f"pynx {self._pynx_version}"
+            )
 
             # Create parameter groups
             try:
@@ -659,10 +662,10 @@ class Dataset:
                         image_3.create_dataset("voxel_sizes",
                                                data=fi["output"]["voxel_sizes"])
 
-                        image_3.create_dataset("q_com",
-                                               data=fi["output"]["q_com"])
+                        image_3.create_dataset("q_bragg",
+                                               data=fi["output"]["q_bragg"])
 
-                        # Need to add trans matrix here
+                        # Need to add transformation matrix here
 
                     image_3.attrs['signal'] = 'phase'
 
@@ -686,7 +689,7 @@ class Dataset:
         print(
             "\n###########################################"
             "#############################################"
-            f"Saved file as {self.scan_folder}{self.sample_name}{self.scan}.cxi"
+            f"\nSaved file as {self.scan_folder}{self.sample_name}{self.scan}.cxi"
             "\n\tUse Dataset.postprocessing_output_file attribute."
             "\n###########################################"
             "#############################################"
