@@ -52,18 +52,17 @@ class Plotter:
         'plot'.
 
         :param filename: path to data, supported files extensions are .cxi,
-         .npy or .npz
+            .npy or .npz
         :param data_array: a np.ndarray
         :param plot: str in [
-            '2D', 'slices', 'contour_slices',
-            'sum_slices', 'sum_contour_slices',
-            '3D', False,
-         ]
+            '2D', 'slices', 'contour_slices', 'sum_slices',
+            'sum_contour_slices', '3D', False,
+            ]
         :param log: True to have a logarithmic scale
-         False to have a linear scale
+            False to have a linear scale
         :param cmap: matplotlib cmap used for plot, default 'YlGnBu_r'
-         Other possible values are 'Cool', 'Gray', 'Gray_r', 'Hot', 'Hsv',
-         'Inferno', 'Jet', 'Plasma', 'Rainbow', 'Viridis'
+            Other possible values are 'Cool', 'Gray', 'Gray_r', 'Hot', 'Hsv',
+            'Inferno', 'Jet', 'Plasma', 'Rainbow', 'Viridis'
         :param figsize: default (10, 10)
         :param fontsize: default 15
         """
@@ -95,6 +94,7 @@ class Plotter:
             )
 
     def init_plot(self):
+        """Initialize plotting widget with the given parameters"""
         if self.plot == "2D":
             plot_data(
                 data_array=self.data_array,
@@ -168,13 +168,19 @@ class Plotter:
                         'entry_1/data_1/data'][()]
 
                 except (KeyError, OSError):
-                    print("""
-                        The file could not be loaded, verify that you are
-                        loading a file with an hdf5 architecture (.nxs, .cxi,
-                        .h5, ...) and that the file exists. Otherwise, verify
-                        that the data is saved in f.root.entry_1.data_1.data[:],
-                        as it should be following cxi conventions.
-                        """)
+                    try:
+                        self.data_array = h5.File(self.filename, mode='r')[
+                            'entry_1/image_1/data'][()]
+                    except (KeyError, OSError):
+                        print(
+                            "The file could not be loaded, verify that you are"
+                            "loading a file with an hdf5 architecture (.nxs, "
+                            ".cxi, .h5, ...) and that the file exists. Otherwise"
+                            ", verify that the data is saved in "
+                            "f.root.entry_1.data_1.data[:],"
+                            "or f.root.entry_1.image_1.data[:], as it should be"
+                            "following cxi conventions."
+                        )
 
             elif self.filename.endswith(".h5"):
                 try:
@@ -194,13 +200,15 @@ class Plotter:
                         # Due to labelling of axes x,y,z and not z,y,x
                         self.data_array = np.swapaxes(self.data_array, 0, 2)
                     except (KeyError, OSError):
-                        raise KeyError("""
-                            The file could not be loaded, verify that you are\
-                            loading a file with an hdf5 architecture (.nxs, .cxi,\
-                            .h5, ...) and that the file exists. Otherwise, verify\
-                            that the data is saved in f.root.entry_1.data_1.data[:],\
-                            as it should be following cxi conventions.\
-                            """)
+                        raise KeyError(
+                            "The file could not be loaded, verify that you are"
+                            "loading a file with an hdf5 architecture (.nxs, "
+                            ".cxi, .h5, ...) and that the file exists. Otherwise"
+                            ", verify that the data is saved in "
+                            "f.root.entry_1.data_1.data[:],"
+                            "or f.root.entry_1.image_1.data[:], as it should be"
+                            "following cxi conventions."
+                        )
 
             # Plot data
             self.init_plot()
@@ -254,9 +262,10 @@ class ThreeDViewer(widgets.Box):
 
         if html_width is not None:
             display(
-                HTML("<style>.container { width:%d%% !important; }\
-                    </style>" % int(html_width)
-                     )
+                HTML(
+                    f"<style>.container \{ width:{int(html_width)}% \
+                    !important; \}</style>"
+                )
             )
 
         # focus_label = widgets.Label(value='Focal distance (cm):')
@@ -349,18 +358,16 @@ class ThreeDViewer(widgets.Box):
         self.toggle_rotate.observe(self.on_animate)
 
         # Future attributes
-        # self.mesh = None
-        # self.color = None
-        # self.d0 = None
-        # self.progress.value = None
+        self.mesh = None
+        self.color = None
+        self.d0 = None
 
         # Create final vertical box with all the widgets
-        self.vbox = widgets.VBox([self.threshold,
-                                  hbox1, hbox_toggle,
-                                  self.colormap,
-                                  # self.colormap_range, # useless for one contour
-                                  self.progress,
-                                  ])
+        self.vbox = widgets.VBox([
+            self.threshold, hbox1, hbox_toggle, self.colormap,
+            # self.colormap_range, # useless for one contour
+            self.progress,
+        ])
 
         # Load data
         if isinstance(input_file, np.ndarray):
@@ -372,7 +379,6 @@ class ThreeDViewer(widgets.Box):
                 display(self.fig)
 
             self.window = widgets.HBox([self.output_view, self.vbox])
-
             display(self.window)
 
         else:
@@ -474,17 +480,18 @@ class ThreeDViewer(widgets.Box):
                 elif 'log' in newv and 'log' not in oldv:
                     self.d0 = self.data
                     data = np.log10(np.maximum(0.1, abs(self.d0)))
-                    self.set_data(data, threshold=np.log10(self.threshold.value))
+                    self.set_data(data, threshold=np.log10(
+                        self.threshold.value))
                     return
             self.on_update_plot()
 
     def set_data(self, data, threshold=None):
-        """Check if data is complex or not
+        """
+        Check if data is complex or not
 
         :param data: data 3d array, complex ot not, to be plotted
         :param threshold: threshold for contour, if None set to max/2
         """
-
         # Update progress bar
         self.progress.value = 5
 
@@ -554,8 +561,7 @@ class ThreeDViewer(widgets.Box):
         self.on_update_plot()
 
     def on_animate(self, v):
-        """Trigger the animation (rotation around vertical axis)
-        """
+        """Trigger the animation (rotation around vertical axis)"""
         if self.pcb_rotate is None:
             self.pcb_rotate = PeriodicCallback(self.callback_rotate, 50.)
         if self.toggle_rotate.value:
@@ -652,8 +658,15 @@ def plot_data(
     elif data_dimensions == 2:
         # Depends on log scale
         if isinstance(log, bool):
+            # Create figure
+            if not figsize:
+                figsize = (10, 10)
+
+            fig, ax = plt.subplots(figsize=figsize)
+
             img = plot_2d_image(
-                data_array, log=log, cmap=cmap, title=title, fontsize=fontsize
+                data_array, log=log, fig=fig, ax=ax, cmap=cmap,
+                title=title, fontsize=fontsize
             )
 
             # Create axis for colorbar
