@@ -161,7 +161,7 @@ class TabPreprocess(widgets.VBox):
 
         self.centering_method_reciprocal_space = widgets.Dropdown(
             options=[
-                "max", "com", "user", "skip"],
+                "max", "com", "max_com"],
             value="max",
             description='Centering of Bragg peak method:',
             continuous_update=False,
@@ -419,6 +419,7 @@ class TabPreprocess(widgets.VBox):
         self.run_preprocess = widgets.ToggleButtons(
             options=[
                 ("False", False),
+                ("Initialize parameters", "init"),
                 ("In GUI.", "GUI"),
                 ("In terminal.", "terminal"),
             ],
